@@ -31,17 +31,63 @@
 
 #include "kml_printer.h"
 #include <ctime>
+#include <sstream>
 #include <glog/logging.h>
 
 using google::LogMessage;
 
-bool Kml_Printer::set_headers(std::string filename)
+bool Kml_Printer::set_headers(std::string filename,  bool time_tag_name)
 {
+
     time_t rawtime;
     struct tm * timeinfo;
     time ( &rawtime );
     timeinfo = localtime ( &rawtime );
-    kml_file.open(filename.c_str());
+    if (time_tag_name)
+        {
+
+
+            std::stringstream strm0;
+            const int year = timeinfo->tm_year - 100;
+            strm0 << year;
+            const int month = timeinfo->tm_mon + 1;
+            if(month < 10)
+                {
+                    strm0 << "0";
+                }
+            strm0 << month;
+            const int day = timeinfo->tm_mday;
+            if(day < 10)
+                {
+                    strm0 << "0";
+                }
+            strm0 << day << "_";
+            const int hour = timeinfo->tm_hour;
+            if(hour < 10)
+                {
+                    strm0 << "0";
+                }
+            strm0 << hour;
+            const int min = timeinfo->tm_min;
+            if(min < 10)
+                {
+                    strm0 << "0";
+                }
+            strm0 << min;
+            const int sec = timeinfo->tm_sec;
+            if(sec < 10)
+                {
+                    strm0 << "0";
+                }
+            strm0 << sec;
+
+            kml_filename = filename + "_" +  strm0.str() + ".kml";
+        }
+    else
+        {
+            kml_filename = filename + ".kml";
+        }
+    kml_file.open(kml_filename.c_str());
     if (kml_file.is_open())
         {
             DLOG(INFO) << "KML printer writing on " << filename.c_str();
@@ -50,17 +96,17 @@ bool Kml_Printer::set_headers(std::string filename)
             kml_file << std::setprecision(14);
             kml_file << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" << std::endl
                     << "<kml xmlns=\"http://www.opengis.net/kml/2.2\">" << std::endl
-                    << "	<Document>" << std::endl
-                    << "	<name>GNSS Track</name>" << std::endl
-                    << "	<description>GNSS-SDR Receiver position log file created at " << asctime (timeinfo)
-                    << "	</description>" << std::endl
+                    << "    <Document>" << std::endl
+                    << "    <name>GNSS Track</name>" << std::endl
+                    << "    <description>GNSS-SDR Receiver position log file created at " << asctime (timeinfo)
+                    << "    </description>" << std::endl
                     << "<Style id=\"yellowLineGreenPoly\">" << std::endl
                     << " <LineStyle>" << std::endl
-                    << " 	<color>7f00ffff</color>" << std::endl
-                    << "		<width>1</width>" << std::endl
-                    << "	</LineStyle>" << std::endl
+                    << "     <color>7f00ffff</color>" << std::endl
+                    << "        <width>1</width>" << std::endl
+                    << "    </LineStyle>" << std::endl
                     << "<PolyStyle>" << std::endl
-                    << "	<color>7f00ff00</color>" << std::endl
+                    << "    <color>7f00ff00</color>" << std::endl
                     << "</PolyStyle>" << std::endl
                     << "</Style>" << std::endl
                     << "<Placemark>" << std::endl
@@ -82,13 +128,15 @@ bool Kml_Printer::set_headers(std::string filename)
 
 
 
-bool Kml_Printer::print_position(const std::shared_ptr<gps_l1_ca_ls_pvt>& position, bool print_average_values)
+bool Kml_Printer::print_position(const std::shared_ptr<Pvt_Solution>& position, bool print_average_values)
 {
     double latitude;
     double longitude;
     double height;
 
-    std::shared_ptr<gps_l1_ca_ls_pvt> position_ = position;
+    positions_printed = true;
+
+    std::shared_ptr<Pvt_Solution> position_ = position;
 
     if (print_average_values == false)
         {
@@ -114,71 +162,12 @@ bool Kml_Printer::print_position(const std::shared_ptr<gps_l1_ca_ls_pvt>& positi
         }
 }
 
-//ToDo: make the class ls_pvt generic and heritate the particular gps/gal/glo ls_pvt in order to
-// reuse kml_printer functions
-bool Kml_Printer::print_position_galileo(const std::shared_ptr<galileo_e1_ls_pvt>& position, bool print_average_values)
-{
-    double latitude;
-    double longitude;
-    double height;
-    std::shared_ptr<galileo_e1_ls_pvt> position_ = position;
-    if (print_average_values == false)
-        {
-            latitude = position_->d_latitude_d;
-            longitude = position_->d_longitude_d;
-            height = position_->d_height_m;
-        }
-    else
-        {
-            latitude = position_->d_avg_latitude_d;
-            longitude = position_->d_avg_longitude_d;
-            height = position_->d_avg_height_m;
-        }
-
-    if (kml_file.is_open())
-        {
-            kml_file << longitude << "," << latitude << "," << height << std::endl;
-            return true;
-        }
-    else
-        {
-            return false;
-        }
-}
-
-bool Kml_Printer::print_position_hybrid(const std::shared_ptr<hybrid_ls_pvt>& position, bool print_average_values)
-{
-    double latitude;
-    double longitude;
-    double height;
-    if (print_average_values == false)
-        {
-            latitude = position->d_latitude_d;
-            longitude = position->d_longitude_d;
-            height = position->d_height_m;
-        }
-    else
-        {
-            latitude = position->d_avg_latitude_d;
-            longitude = position->d_avg_longitude_d;
-            height = position->d_avg_height_m;
-        }
-
-    if (kml_file.is_open())
-        {
-            kml_file << longitude << "," << latitude << "," << height << std::endl;
-            return true;
-        }
-    else
-        {
-            return false;
-        }
-}
 
 bool Kml_Printer::close_file()
 {
     if (kml_file.is_open())
         {
+
             kml_file << "</coordinates>" << std::endl
                      << "</LineString>" << std::endl
                      << "</Placemark>" << std::endl
@@ -195,12 +184,19 @@ bool Kml_Printer::close_file()
 
 
 
-Kml_Printer::Kml_Printer () {}
+Kml_Printer::Kml_Printer ()
+{
+    positions_printed = false;
+}
 
 
 
 Kml_Printer::~Kml_Printer ()
 {
     close_file();
+    if(!positions_printed)
+        {
+            if(remove(kml_filename.c_str()) != 0) LOG(INFO) << "Error deleting temporary KML file";
+        }
 }
 
