@@ -39,7 +39,7 @@
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <glog/logging.h>
 #include <gflags/gflags.h>
-#include "GPS_L1_CA.h"
+
 
 
 using google::LogMessage;
@@ -68,6 +68,7 @@ Nmea_Printer::Nmea_Printer(std::string filename, bool flag_nmea_tty_port, std::s
         {
             nmea_dev_descriptor = -1;
         }
+    print_avg_pos = false;
 }
 
 
@@ -132,7 +133,7 @@ void Nmea_Printer::close_serial ()
 }
 
 
-bool Nmea_Printer::Print_Nmea_Line(const std::shared_ptr<gps_l1_ca_ls_pvt>& pvt_data, bool print_average_values)
+bool Nmea_Printer::Print_Nmea_Line(const std::shared_ptr<Pvt_Solution>& pvt_data, bool print_average_values)
 {
     std::string GPRMC;
     std::string GPGGA;
@@ -141,6 +142,7 @@ bool Nmea_Printer::Print_Nmea_Line(const std::shared_ptr<gps_l1_ca_ls_pvt>& pvt_
 
     // set the new PVT data
     d_PVT_data = pvt_data;
+    print_avg_pos = print_average_values;
 
     // generate the NMEA sentences
 
@@ -173,22 +175,26 @@ bool Nmea_Printer::Print_Nmea_Line(const std::shared_ptr<gps_l1_ca_ls_pvt>& pvt_
     //write to serial device
     if (nmea_dev_descriptor!=-1)
         {
-            try
-            {
-                    int n_bytes_written;
-                    //GPRMC
-                    n_bytes_written = write(nmea_dev_descriptor, GPRMC.c_str(), GPRMC.length());
-                    //GPGGA (Global Positioning System Fixed Data)
-                    n_bytes_written = write(nmea_dev_descriptor, GPGGA.c_str(), GPGGA.length());
-                    //GPGSA
-                    n_bytes_written = write(nmea_dev_descriptor, GPGSA.c_str(), GPGSA.length());
-                    //GPGSV
-                    n_bytes_written = write(nmea_dev_descriptor, GPGSV.c_str(), GPGSV.length());
-            }
-            catch(std::exception ex)
-            {
-                    DLOG(INFO) << "NMEA printer can not write on serial device" << nmea_filename.c_str();;
-            }
+            if(write(nmea_dev_descriptor, GPRMC.c_str(), GPRMC.length()) == -1)
+                {
+                    DLOG(INFO) << "NMEA printer cannot write on serial device" << nmea_devname.c_str();
+                    return false;
+                }
+            if(write(nmea_dev_descriptor, GPGGA.c_str(), GPGGA.length()) == -1)
+                {
+                    DLOG(INFO) << "NMEA printer cannot write on serial device" << nmea_devname.c_str();
+                    return false;
+                }
+            if(write(nmea_dev_descriptor, GPGSA.c_str(), GPGSA.length()) == -1)
+                {
+                    DLOG(INFO) << "NMEA printer cannot write on serial device" << nmea_devname.c_str();
+                    return false;
+                }
+            if(write(nmea_dev_descriptor, GPGSV.c_str(), GPGSV.length()) == -1)
+                {
+                    DLOG(INFO) << "NMEA printer cannot write on serial device" << nmea_devname.c_str();
+                    return false;
+                }
         }
     return true;
 }
@@ -361,7 +367,7 @@ std::string Nmea_Printer::get_GPRMC()
             sentence_str << ",V";
         };
 
-    if (d_PVT_data->d_flag_averaging == true)
+    if (print_avg_pos == true)
         {
             // Latitude ddmm.mmmm,(N or S)
             sentence_str << "," << latitude_to_hm(d_PVT_data->d_avg_latitude_d);
