@@ -30,11 +30,9 @@
  */
 
 #include "galileo_e1_pcps_cccwsr_ambiguous_acquisition.h"
-#include <iostream>
 #include <boost/lexical_cast.hpp>
 #include <boost/math/distributions/exponential.hpp>
 #include <glog/logging.h>
-#include <volk/volk.h>
 #include "galileo_e1_signal_processing.h"
 #include "Galileo_E1.h"
 #include "configuration_interface.h"
@@ -43,9 +41,8 @@ using google::LogMessage;
 
 GalileoE1PcpsCccwsrAmbiguousAcquisition::GalileoE1PcpsCccwsrAmbiguousAcquisition(
         ConfigurationInterface* configuration, std::string role,
-        unsigned int in_streams, unsigned int out_streams,
-        boost::shared_ptr<gr::msg_queue> queue) :
-        role_(role), in_streams_(in_streams), out_streams_(out_streams), queue_(queue)
+        unsigned int in_streams, unsigned int out_streams) :
+        role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
     configuration_ = configuration;
     std::string default_item_type = "gr_complex";
@@ -53,13 +50,12 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::GalileoE1PcpsCccwsrAmbiguousAcquisition
 
     DLOG(INFO) << "role " << role;
 
-    item_type_ = configuration_->property(role + ".item_type",
-            default_item_type);
+    item_type_ = configuration_->property(role + ".item_type", default_item_type);
 
     fs_in_ = configuration_->property("GNSS-SDR.internal_fs_hz", 4000000);
-    if_ = configuration_->property(role + ".ifreq", 0);
+    if_ = configuration_->property(role + ".if", 0);
     dump_ = configuration_->property(role + ".dump", false);
-    shift_resolution_ = configuration_->property(role + ".doppler_max", 15);
+    doppler_max_ = configuration_->property(role + ".doppler_max", 5000);
     sampled_ms_ = configuration_->property(role + ".coherent_integration_time_ms", 4);
 
     if (sampled_ms_ % 4 != 0)
@@ -93,8 +89,8 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::GalileoE1PcpsCccwsrAmbiguousAcquisition
         {
             item_size_ = sizeof(gr_complex);
             acquisition_cc_ = pcps_cccwsr_make_acquisition_cc(sampled_ms_, max_dwells_,
-                    shift_resolution_, if_, fs_in_, samples_per_ms, code_length_,
-                    queue_, dump_, dump_filename_);
+                    doppler_max_, if_, fs_in_, samples_per_ms, code_length_,
+                    dump_, dump_filename_);
             stream_to_vector_ = gr::blocks::stream_to_vector::make(item_size_, vector_length_);
             DLOG(INFO) << "stream_to_vector("
                     << stream_to_vector_->unique_id() << ")";
@@ -106,12 +102,11 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::GalileoE1PcpsCccwsrAmbiguousAcquisition
             item_size_ = sizeof(gr_complex);
             LOG(WARNING) << item_type_ << " unknown acquisition item type";
         }
-    gnss_synchro_ = 0;
-    threshold_ = 0.0;
-    doppler_max_ = 5000;
-    doppler_step_ = 250;
-    channel_internal_queue_ = 0;
+
     channel_ = 0;
+    threshold_ = 0.0;
+    doppler_step_ = 0;
+    gnss_synchro_ = 0;
 }
 
 
@@ -122,8 +117,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::~GalileoE1PcpsCccwsrAmbiguousAcquisitio
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_channel(unsigned int channel)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_channel(unsigned int channel)
 {
     channel_ = channel;
     if (item_type_.compare("gr_complex") == 0)
@@ -133,36 +127,33 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_channel(unsigned int channel)
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_threshold(float threshold)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_threshold(float threshold)
 {
+    //    float pfa = configuration_->property(role_+ boost::lexical_cast<std::string>(channel_) + ".pfa", 0.0);
 
-//    float pfa = configuration_->property(role_+ boost::lexical_cast<std::string>(channel_) + ".pfa", 0.0);
+    //    if(pfa==0.0) pfa = configuration_->property(role_+".pfa", 0.0);
 
-//    if(pfa==0.0) pfa = configuration_->property(role_+".pfa", 0.0);
-
-//    if(pfa==0.0)
-//        {
-//            threshold_ = threshold;
-//        }
-//    else
-//        {
-//            threshold_ = calculate_threshold(pfa);
-//        }
+    //    if(pfa==0.0)
+    //        {
+    //            threshold_ = threshold;
+    //        }
+    //    else
+    //        {
+    //            threshold_ = calculate_threshold(pfa);
+    //        }
 
     threshold_ = threshold;
 
-	DLOG(INFO) <<"Channel "<<channel_<<" Threshold = " << threshold_;
+    DLOG(INFO) <<"Channel "<<channel_<<" Threshold = " << threshold_;
 
-	if (item_type_.compare("gr_complex") == 0)
+    if (item_type_.compare("gr_complex") == 0)
         {
             acquisition_cc_->set_threshold(threshold_);
         }
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_max(unsigned int doppler_max)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_max(unsigned int doppler_max)
 {
     doppler_max_ = doppler_max;
 
@@ -173,8 +164,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_max(unsigned int doppler_ma
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_step(unsigned int doppler_step)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_step(unsigned int doppler_step)
 {
     doppler_step_ = doppler_step;
     if (item_type_.compare("gr_complex") == 0)
@@ -183,21 +173,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_doppler_step(unsigned int doppler_s
         }
 }
 
-
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_channel_queue(
-        concurrent_queue<int> *channel_internal_queue)
-{
-    channel_internal_queue_ = channel_internal_queue;
-    if (item_type_.compare("gr_complex") == 0)
-        {
-            acquisition_cc_->set_channel_queue(channel_internal_queue_);
-        }
-}
-
-
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_gnss_synchro(
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_gnss_synchro(
         Gnss_Synchro* gnss_synchro)
 {
     gnss_synchro_ = gnss_synchro;
@@ -208,8 +184,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_gnss_synchro(
 }
 
 
-signed int
-GalileoE1PcpsCccwsrAmbiguousAcquisition::mag()
+signed int GalileoE1PcpsCccwsrAmbiguousAcquisition::mag()
 {
     if (item_type_.compare("gr_complex") == 0)
         {
@@ -222,22 +197,20 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::mag()
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::init()
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::init()
 {
     acquisition_cc_->init();
     set_local_code();
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_local_code()
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_local_code()
 {
     if (item_type_.compare("gr_complex") == 0)
         {
             bool cboc = configuration_->property(
                     "Acquisition" + boost::lexical_cast<std::string>(channel_)
-                            + ".cboc", false);
+                    + ".cboc", false);
 
             char signal[3];
 
@@ -256,8 +229,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_local_code()
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::reset()
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::reset()
 {
     if (item_type_.compare("gr_complex") == 0)
         {
@@ -265,10 +237,9 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::reset()
         }
 }
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::set_state(int state)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::set_state(int state)
 {
-        acquisition_cc_->set_state(state);
+    acquisition_cc_->set_state(state);
 }
 
 
@@ -276,12 +247,11 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::set_state(int state)
 float GalileoE1PcpsCccwsrAmbiguousAcquisition::calculate_threshold(float pfa)
 {
     if(pfa){ /* Not implemented*/};
-	return 0.0;
+    return 0.0;
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::connect(gr::top_block_sptr top_block)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::connect(gr::top_block_sptr top_block)
 {
     if (item_type_.compare("gr_complex") == 0)
         {
@@ -291,8 +261,7 @@ GalileoE1PcpsCccwsrAmbiguousAcquisition::connect(gr::top_block_sptr top_block)
 }
 
 
-void
-GalileoE1PcpsCccwsrAmbiguousAcquisition::disconnect(gr::top_block_sptr top_block)
+void GalileoE1PcpsCccwsrAmbiguousAcquisition::disconnect(gr::top_block_sptr top_block)
 {
     if (item_type_.compare("gr_complex") == 0)
         {
