@@ -33,7 +33,6 @@
 #define GNSS_SDR_GALILEO_E1_PCPS_QUICKSYNC_AMBIGUOUS_ACQUISITION_H_
 
 #include <string>
-#include <gnuradio/msg_queue.h>
 #include <gnuradio/blocks/stream_to_vector.h>
 #include "gnss_synchro.h"
 #include "acquisition_interface.h"
@@ -51,7 +50,7 @@ class GalileoE1PcpsQuickSyncAmbiguousAcquisition: public AcquisitionInterface
 public:
     GalileoE1PcpsQuickSyncAmbiguousAcquisition(ConfigurationInterface* configuration,
             std::string role, unsigned int in_streams,
-            unsigned int out_streams, boost::shared_ptr<gr::msg_queue> queue);
+            unsigned int out_streams);
 
     virtual ~GalileoE1PcpsQuickSyncAmbiguousAcquisition();
 
@@ -104,11 +103,6 @@ public:
      */
     void set_doppler_step(unsigned int doppler_step);
 
-    /*!
-     * \brief Set tracking channel internal queue
-     */
-    void set_channel_queue(concurrent_queue<int> *channel_internal_queue);
-
     /*!
      * \brief Initializes acquisition algorithm.
      */
@@ -147,7 +141,6 @@ private:
     float threshold_;
     unsigned int doppler_max_;
     unsigned int doppler_step_;
-    unsigned int shift_resolution_;
     unsigned int sampled_ms_;
     unsigned int max_dwells_;
     unsigned int folding_factor_;
@@ -160,8 +153,6 @@ private:
     std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    boost::shared_ptr<gr::msg_queue> queue_;
-    concurrent_queue<int> *channel_internal_queue_;
     float calculate_threshold(float pfa);
 };
 
