@@ -30,11 +30,8 @@
  */
 
 #include "gps_l1_ca_pcps_tong_acquisition.h"
-#include <iostream>
-#include <stdexcept>
 #include <boost/math/distributions/exponential.hpp>
 #include <glog/logging.h>
-#include <gnuradio/msg_queue.h>
 #include "gps_sdr_signal_processing.h"
 #include "GPS_L1_CA.h"
 #include "configuration_interface.h"
@@ -44,9 +41,8 @@ using google::LogMessage;
 
 GpsL1CaPcpsTongAcquisition::GpsL1CaPcpsTongAcquisition(
         ConfigurationInterface* configuration, std::string role,
-        unsigned int in_streams, unsigned int out_streams,
-        gr::msg_queue::sptr queue) :
-    role_(role), in_streams_(in_streams), out_streams_(out_streams), queue_(queue)
+        unsigned int in_streams, unsigned int out_streams) :
+    role_(role), in_streams_(in_streams), out_streams_(out_streams)
 {
     configuration_ = configuration;
     std::string default_item_type = "gr_complex";
@@ -54,20 +50,19 @@ GpsL1CaPcpsTongAcquisition::GpsL1CaPcpsTongAcquisition(
 
     DLOG(INFO) << "role " << role;
 
-    item_type_ = configuration_->property(role + ".item_type",
-            default_item_type);
+    item_type_ = configuration_->property(role + ".item_type", default_item_type);
 
     fs_in_ = configuration_->property("GNSS-SDR.internal_fs_hz", 2048000);
-    if_ = configuration_->property(role + ".ifreq", 0);
+    if_ = configuration_->property(role + ".if", 0);
     dump_ = configuration_->property(role + ".dump", false);
-    shift_resolution_ = configuration_->property(role + ".doppler_max", 15);
+    doppler_max_ = configuration->property(role + ".doppler_max", 5000);
     sampled_ms_ = configuration_->property(role + ".coherent_integration_time_ms", 1);
 
     tong_init_val_ = configuration->property(role + ".tong_init_val", 1);
     tong_max_val_ = configuration->property(role + ".tong_max_val", 2);
+    tong_max_dwells_ = configuration->property(role + ".tong_max_dwells", tong_max_val_ + 1);
 
-    dump_filename_ = configuration_->property(role + ".dump_filename",
-            default_dump_filename);
+    dump_filename_ = configuration_->property(role + ".dump_filename", default_dump_filename);
 
     //--- Find number of samples per spreading code -------------------------
     code_length_ = round(fs_in_
@@ -75,21 +70,19 @@ GpsL1CaPcpsTongAcquisition::GpsL1CaPcpsTongAcquisition(
 
     vector_length_ = code_length_ * sampled_ms_;
 
-    code_= new gr_complex[vector_length_];
+    code_ = new gr_complex[vector_length_];
 
     if (item_type_.compare("gr_complex") == 0)
         {
             item_size_ = sizeof(gr_complex);
-            acquisition_cc_ = pcps_tong_make_acquisition_cc(sampled_ms_, shift_resolution_, if_, fs_in_,
-                                    code_length_, code_length_, tong_init_val_, tong_max_val_,
-                                    queue_, dump_, dump_filename_);
+            acquisition_cc_ = pcps_tong_make_acquisition_cc(sampled_ms_, doppler_max_, if_, fs_in_,
+                                    code_length_, code_length_, tong_init_val_, tong_max_val_, tong_max_dwells_,
+                                    dump_, dump_filename_);
 
             stream_to_vector_ = gr::blocks::stream_to_vector::make(item_size_, vector_length_);
 
-            DLOG(INFO) << "stream_to_vector(" << stream_to_vector_->unique_id()
-                    << ")";
-            DLOG(INFO) << "acquisition(" << acquisition_cc_->unique_id()
-                    << ")";
+            DLOG(INFO) << "stream_to_vector(" << stream_to_vector_->unique_id() << ")";
+            DLOG(INFO) << "acquisition(" << acquisition_cc_->unique_id() << ")";
         }
     else
         {
@@ -97,13 +90,10 @@ GpsL1CaPcpsTongAcquisition::GpsL1CaPcpsTongAcquisition(
             LOG(WARNING) << item_type_ << " unknown acquisition item type";
         }
 
-    gnss_synchro_ = 0;
-    threshold_ = 0.0;
-    doppler_max_ = 5000;
-    doppler_step_ = 250;
-    channel_internal_queue_ = 0;
     channel_ = 0;
-    bit_transition_flag_ = false;
+    threshold_ = 0.0;
+    doppler_step_ = 0;
+    gnss_synchro_ = 0;
 }
 
 
@@ -125,22 +115,22 @@ void GpsL1CaPcpsTongAcquisition::set_channel(unsigned int channel)
 
 void GpsL1CaPcpsTongAcquisition::set_threshold(float threshold)
 {
-	float pfa = configuration_->property(role_ + boost::lexical_cast<std::string>(channel_) + ".pfa", 0.0);
+    float pfa = configuration_->property(role_ + boost::lexical_cast<std::string>(channel_) + ".pfa", 0.0);
 
-	if(pfa==0.0)
+    if(pfa == 0.0)
         {
-                 pfa = configuration_->property(role_+".pfa", 0.0);
+            pfa = configuration_->property(role_+".pfa", 0.0);
+        }
+    if(pfa == 0.0)
+        {
+            threshold_ = threshold;
+        }
+    else
+        {
+            threshold_ = calculate_threshold(pfa);
         }
-	if(pfa==0.0)
-		{
-			threshold_ = threshold;
-		}
-	else
-		{
-			threshold_ = calculate_threshold(pfa);
-		}
 
-	DLOG(INFO) <<"Channel "<<channel_<<" Threshold = " << threshold_;
+    DLOG(INFO) << "Channel " << channel_ << "  Threshold = " << threshold_;
 
     if (item_type_.compare("gr_complex") == 0)
         {
@@ -170,17 +160,6 @@ void GpsL1CaPcpsTongAcquisition::set_doppler_step(unsigned int doppler_step)
 }
 
 
-void GpsL1CaPcpsTongAcquisition::set_channel_queue(
-        concurrent_queue<int> *channel_internal_queue)
-{
-    channel_internal_queue_ = channel_internal_queue;
-    if (item_type_.compare("gr_complex") == 0)
-        {
-            acquisition_cc_->set_channel_queue(channel_internal_queue_);
-        }
-}
-
-
 void GpsL1CaPcpsTongAcquisition::set_gnss_synchro(Gnss_Synchro* gnss_synchro)
 {
     gnss_synchro_ = gnss_synchro;
@@ -230,6 +209,7 @@ void GpsL1CaPcpsTongAcquisition::set_local_code()
     }
 }
 
+
 void GpsL1CaPcpsTongAcquisition::reset()
 {
     if (item_type_.compare("gr_complex") == 0)
@@ -238,6 +218,7 @@ void GpsL1CaPcpsTongAcquisition::reset()
         }
 }
 
+
 void GpsL1CaPcpsTongAcquisition::set_state(int state)
 {
     if (item_type_.compare("gr_complex") == 0)
@@ -246,28 +227,29 @@ void GpsL1CaPcpsTongAcquisition::set_state(int state)
     }
 }
 
+
 float GpsL1CaPcpsTongAcquisition::calculate_threshold(float pfa)
 {
-	//Calculate the threshold
-
-	unsigned int frequency_bins = 0;
-	for (int doppler = (int)(-doppler_max_); doppler <= (int)doppler_max_; doppler += doppler_step_)
+    //Calculate the threshold
+    unsigned int frequency_bins = 0;
+    for (int doppler = (int)(-doppler_max_); doppler <= (int)doppler_max_; doppler += doppler_step_)
         {
             frequency_bins++;
         }
 
-	DLOG(INFO) << "Channel "<< channel_ <<"   Pfa = "<< pfa;
+    DLOG(INFO) << "Channel "<< channel_ <<"   Pfa = "<< pfa;
 
-	unsigned int ncells = vector_length_ * frequency_bins;
-	double exponent = 1 / static_cast<double>(ncells);
-	double val = pow(1.0 - pfa,exponent);
-	double lambda = double(vector_length_);
-	boost::math::exponential_distribution<double> mydist (lambda);
-	float threshold = (float)quantile(mydist, val);
+    unsigned int ncells = vector_length_ * frequency_bins;
+    double exponent = 1 / static_cast<double>(ncells);
+    double val = pow(1.0 - pfa,exponent);
+    double lambda = double(vector_length_);
+    boost::math::exponential_distribution<double> mydist (lambda);
+    float threshold = (float)quantile(mydist, val);
 
-	return threshold;
+    return threshold;
 }
 
+
 void GpsL1CaPcpsTongAcquisition::connect(gr::top_block_sptr top_block)
 {
     if (item_type_.compare("gr_complex") == 0)
