@@ -36,39 +36,38 @@
 #include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <volk/volk.h>
-#include "nco_lib.h"
+#include <volk_gnsssdr/volk_gnsssdr.h>
 #include "concurrent_map.h"
-#include "gnss_signal_processing.h"
 #include "gps_sdr_signal_processing.h"
 #include "control_message_factory.h"
-
+#include "GPS_L1_CA.h"
 
 using google::LogMessage;
 
 pcps_acquisition_fine_doppler_cc_sptr pcps_make_acquisition_fine_doppler_cc(
         int max_dwells, unsigned int sampled_ms, int doppler_max, int doppler_min, long freq,
-        long fs_in, int samples_per_ms, boost::shared_ptr<gr::msg_queue> queue, bool dump,
+        long fs_in, int samples_per_ms, bool dump,
         std::string dump_filename)
 {
 
     return pcps_acquisition_fine_doppler_cc_sptr(
             new pcps_acquisition_fine_doppler_cc(max_dwells, sampled_ms, doppler_max, doppler_min, freq,
-                    fs_in, samples_per_ms, queue, dump, dump_filename));
+                    fs_in, samples_per_ms, dump, dump_filename));
 }
 
 
 
 pcps_acquisition_fine_doppler_cc::pcps_acquisition_fine_doppler_cc(
         int max_dwells, unsigned int sampled_ms, int doppler_max, int doppler_min, long freq,
-        long fs_in, int samples_per_ms, boost::shared_ptr<gr::msg_queue> queue, bool dump,
+        long fs_in, int samples_per_ms, bool dump,
         std::string dump_filename) :
-		        gr::block("pcps_acquisition_fine_doppler_cc",
-		                gr::io_signature::make(1, 1, sizeof(gr_complex)),
-		                gr::io_signature::make(0, 0, sizeof(gr_complex)))
+                gr::block("pcps_acquisition_fine_doppler_cc",
+                        gr::io_signature::make(1, 1, sizeof(gr_complex)),
+                        gr::io_signature::make(0, 0, sizeof(gr_complex)))
 {
+    this->message_port_register_out(pmt::mp("events"));
     d_sample_counter = 0;    // SAMPLE COUNTER
     d_active = false;
-    d_queue = queue;
     d_freq = freq;
     d_fs_in = fs_in;
     d_samples_per_ms = samples_per_ms;
@@ -81,9 +80,9 @@ pcps_acquisition_fine_doppler_cc::pcps_acquisition_fine_doppler_cc(
     d_gnuradio_forecast_samples = d_fft_size;
     d_input_power = 0.0;
     d_state = 0;
-    d_carrier = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
-    d_fft_codes = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
-    d_magnitude = static_cast<float*>(volk_malloc(d_fft_size * sizeof(float), volk_get_alignment()));
+    d_carrier = static_cast<gr_complex*>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
+    d_fft_codes = static_cast<gr_complex*>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
+    d_magnitude = static_cast<float*>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
 
     // Direct FFT
     d_fft_if = new gr::fft::fft_complex(d_fft_size, true);
@@ -105,7 +104,6 @@ pcps_acquisition_fine_doppler_cc::pcps_acquisition_fine_doppler_cc(
     d_code_phase = 0;
     d_doppler_freq = 0;
     d_test_statistics = 0;
-    d_channel_internal_queue = 0;
     d_well_count = 0;
     d_channel = 0;
 }
@@ -120,7 +118,7 @@ void pcps_acquisition_fine_doppler_cc::set_doppler_step(unsigned int doppler_ste
     d_grid_data = new float*[d_num_doppler_points];
     for (int i = 0; i < d_num_doppler_points; i++)
         {
-            d_grid_data[i] = static_cast<float*>(volk_malloc(d_fft_size * sizeof(float), volk_get_alignment()));
+            d_grid_data[i] = static_cast<float*>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
         }
     update_carrier_wipeoff();
 }
@@ -129,7 +127,7 @@ void pcps_acquisition_fine_doppler_cc::free_grid_memory()
 {
     for (int i = 0; i < d_num_doppler_points; i++)
         {
-            volk_free(d_grid_data[i]);
+            volk_gnsssdr_free(d_grid_data[i]);
             delete[] d_grid_doppler_wipeoffs[i];
         }
     delete d_grid_data;
@@ -138,9 +136,9 @@ void pcps_acquisition_fine_doppler_cc::free_grid_memory()
 
 pcps_acquisition_fine_doppler_cc::~pcps_acquisition_fine_doppler_cc()
 {
-    volk_free(d_carrier);
-    volk_free(d_fft_codes);
-    volk_free(d_magnitude);
+    volk_gnsssdr_free(d_carrier);
+    volk_gnsssdr_free(d_fft_codes);
+    volk_gnsssdr_free(d_magnitude);
     delete d_ifft;
     delete d_fft_if;
     if (d_dump)
@@ -163,6 +161,12 @@ void pcps_acquisition_fine_doppler_cc::set_local_code(std::complex<float> * code
 
 void pcps_acquisition_fine_doppler_cc::init()
 {
+    d_gnss_synchro->Flag_valid_acquisition = false;
+    d_gnss_synchro->Flag_valid_symbol_output = false;
+    d_gnss_synchro->Flag_valid_pseudorange = false;
+    d_gnss_synchro->Flag_valid_word = false;
+    d_gnss_synchro->Flag_preamble = false;
+
     d_gnss_synchro->Acq_delay_samples = 0.0;
     d_gnss_synchro->Acq_doppler_hz = 0.0;
     d_gnss_synchro->Acq_samplestamp_samples = 0;
@@ -174,21 +178,26 @@ void pcps_acquisition_fine_doppler_cc::init()
 void pcps_acquisition_fine_doppler_cc::forecast (int noutput_items,
         gr_vector_int &ninput_items_required)
 {
-    ninput_items_required[0] = d_gnuradio_forecast_samples ; //set the required available samples in each call
+    if (noutput_items != 0)
+        {
+            ninput_items_required[0] = d_gnuradio_forecast_samples ; //set the required available samples in each call
+        }
 }
 
 
 void pcps_acquisition_fine_doppler_cc::reset_grid()
 {
     d_well_count = 0;
-    for (int i=0; i<d_num_doppler_points; i++)
+    for (int i = 0; i < d_num_doppler_points; i++)
         {
-            for (unsigned int j=0; j < d_fft_size; j++)
+            for (unsigned int j = 0; j < d_fft_size; j++)
                 {
                     d_grid_data[i][j] = 0.0;
                 }
         }
 }
+
+
 void pcps_acquisition_fine_doppler_cc::update_carrier_wipeoff()
 {
     // create the carrier Doppler wipeoff signals
@@ -197,13 +206,14 @@ void pcps_acquisition_fine_doppler_cc::update_carrier_wipeoff()
     d_grid_doppler_wipeoffs = new gr_complex*[d_num_doppler_points];
     for (int doppler_index = 0; doppler_index < d_num_doppler_points; doppler_index++)
         {
-
             doppler_hz = d_config_doppler_min + d_doppler_step*doppler_index;
             // doppler search steps
             // compute the carrier doppler wipe-off signal and store it
-            phase_step_rad = static_cast<float>(GPS_TWO_PI) * doppler_hz / static_cast<float>(d_fs_in);
+            phase_step_rad = static_cast<float>(GPS_TWO_PI) * ( d_freq + doppler_hz ) / static_cast<float>(d_fs_in);
             d_grid_doppler_wipeoffs[doppler_index] = new gr_complex[d_fft_size];
-            fxp_nco(d_grid_doppler_wipeoffs[doppler_index], d_fft_size,0, phase_step_rad);
+            float _phase[1];
+            _phase[0] = 0;
+            volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], - phase_step_rad, _phase, d_fft_size);
         }
 }
 
@@ -212,12 +222,12 @@ double pcps_acquisition_fine_doppler_cc::search_maximum()
     float magt = 0.0;
     float fft_normalization_factor;
     int index_doppler = 0;
-    unsigned int tmp_intex_t;
-    unsigned int index_time = 0;
+    uint32_t tmp_intex_t = 0;
+    uint32_t index_time = 0;
 
     for (int i=0;i<d_num_doppler_points;i++)
         {
-            volk_32f_index_max_16u(&tmp_intex_t, d_grid_data[i], d_fft_size);
+            volk_gnsssdr_32f_index_max_32u(&tmp_intex_t, d_grid_data[i], d_fft_size);
             if (d_grid_data[i][tmp_intex_t] > magt)
                 {
                     magt = d_grid_data[i][tmp_intex_t];
@@ -282,7 +292,7 @@ int pcps_acquisition_fine_doppler_cc::compute_and_accumulate_grid(gr_vector_cons
 
 
     // 2- Doppler frequency search loop
-    float* p_tmp_vector = static_cast<float*>(volk_malloc(d_fft_size * sizeof(float), volk_get_alignment()));
+    float* p_tmp_vector = static_cast<float*>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
 
     for (int doppler_index = 0; doppler_index < d_num_doppler_points; doppler_index++)
         {
@@ -308,15 +318,15 @@ int pcps_acquisition_fine_doppler_cc::compute_and_accumulate_grid(gr_vector_cons
 
         }
 
-    volk_free(p_tmp_vector);
+    volk_gnsssdr_free(p_tmp_vector);
     return d_fft_size;
 }
 
-int pcps_acquisition_fine_doppler_cc::estimate_Doppler(gr_vector_const_void_star &input_items, int available_samples)
+int pcps_acquisition_fine_doppler_cc::estimate_Doppler(gr_vector_const_void_star &input_items)
 {
 
     // Direct FFT
-    int zero_padding_factor = 16;
+    int zero_padding_factor = 2;
     int fft_size_extended = d_fft_size * zero_padding_factor;
     gr::fft::fft_complex *fft_operator = new gr::fft::fft_complex(fft_size_extended, true);
 
@@ -324,7 +334,7 @@ int pcps_acquisition_fine_doppler_cc::estimate_Doppler(gr_vector_const_void_star
     memset(fft_operator->get_inbuf(), 0, fft_size_extended * sizeof(gr_complex));
 
     //1. generate local code aligned with the acquisition code phase estimation
-    gr_complex *code_replica = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
+    gr_complex *code_replica = static_cast<gr_complex*>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
 
     gps_l1_ca_code_gen_complex_sampled(code_replica, d_gnss_synchro->PRN, d_fs_in, 0);
 
@@ -345,12 +355,12 @@ int pcps_acquisition_fine_doppler_cc::estimate_Doppler(gr_vector_const_void_star
     fft_operator->execute();
 
     // 4. Compute the magnitude and find the maximum
-    float* p_tmp_vector = static_cast<float*>(volk_malloc(fft_size_extended * sizeof(float), volk_get_alignment()));
+    float* p_tmp_vector = static_cast<float*>(volk_gnsssdr_malloc(fft_size_extended * sizeof(float), volk_gnsssdr_get_alignment()));
 
     volk_32fc_magnitude_squared_32f(p_tmp_vector, fft_operator->get_outbuf(), fft_size_extended);
 
-    unsigned int tmp_index_freq = 0;
-    volk_32f_index_max_16u(&tmp_index_freq, p_tmp_vector, fft_size_extended);
+    uint32_t tmp_index_freq = 0;
+    volk_gnsssdr_32f_index_max_32u(&tmp_index_freq, p_tmp_vector, fft_size_extended);
 
     //case even
     int counter = 0;
@@ -382,60 +392,60 @@ int pcps_acquisition_fine_doppler_cc::estimate_Doppler(gr_vector_const_void_star
             DLOG(INFO) <<  "Error estimating fine frequency Doppler";
             //debug log
             //
-            //		std::cout<<"FFT maximum present at "<<fftFreqBins[tmp_index_freq]<<" [Hz]"<<std::endl;
-            //		std::stringstream filename;
-            //		std::streamsize n = sizeof(gr_complex) * (d_fft_size);
+            //        std::cout<<"FFT maximum present at "<<fftFreqBins[tmp_index_freq]<<" [Hz]"<<std::endl;
+            //        std::stringstream filename;
+            //        std::streamsize n = sizeof(gr_complex) * (d_fft_size);
             //
-            //		filename.str("");
-            //		filename << "../data/code_prn_" << d_gnss_synchro->PRN << ".dat";
-            //		d_dump_file.open(filename.str().c_str(), std::ios::out
-            //				| std::ios::binary);
-            //		d_dump_file.write((char*)code_replica, n); //write directly |abs(x)|^2 in this Doppler bin?
-            //		d_dump_file.close();
+            //        filename.str("");
+            //        filename << "../data/code_prn_" << d_gnss_synchro->PRN << ".dat";
+            //        d_dump_file.open(filename.str().c_str(), std::ios::out
+            //                | std::ios::binary);
+            //        d_dump_file.write((char*)code_replica, n); //write directly |abs(x)|^2 in this Doppler bin?
+            //        d_dump_file.close();
             //
-            //		filename.str("");
-            //		filename << "../data/signal_prn_" << d_gnss_synchro->PRN << ".dat";
-            //		d_dump_file.open(filename.str().c_str(), std::ios::out
-            //				| std::ios::binary);
-            //		d_dump_file.write((char*)in, n); //write directly |abs(x)|^2 in this Doppler bin?
-            //		d_dump_file.close();
+            //        filename.str("");
+            //        filename << "../data/signal_prn_" << d_gnss_synchro->PRN << ".dat";
+            //        d_dump_file.open(filename.str().c_str(), std::ios::out
+            //                | std::ios::binary);
+            //        d_dump_file.write((char*)in, n); //write directly |abs(x)|^2 in this Doppler bin?
+            //        d_dump_file.close();
             //
             //
-            //		n = sizeof(float) * (fft_size_extended);
-            //		filename.str("");
-            //		filename << "../data/fft_prn_" << d_gnss_synchro->PRN << ".dat";
-            //		d_dump_file.open(filename.str().c_str(), std::ios::out
-            //				| std::ios::binary);
-            //		d_dump_file.write((char*)p_tmp_vector, n); //write directly |abs(x)|^2 in this Doppler bin?
-            //		d_dump_file.close();
+            //        n = sizeof(float) * (fft_size_extended);
+            //        filename.str("");
+            //        filename << "../data/fft_prn_" << d_gnss_synchro->PRN << ".dat";
+            //        d_dump_file.open(filename.str().c_str(), std::ios::out
+            //                | std::ios::binary);
+            //        d_dump_file.write((char*)p_tmp_vector, n); //write directly |abs(x)|^2 in this Doppler bin?
+            //        d_dump_file.close();
         }
 
 
     // free memory!!
     delete fft_operator;
-    volk_free(code_replica);
-    volk_free(p_tmp_vector);
+    volk_gnsssdr_free(code_replica);
+    volk_gnsssdr_free(p_tmp_vector);
     return d_fft_size;
 }
 
 
 int pcps_acquisition_fine_doppler_cc::general_work(int noutput_items,
-        gr_vector_int &ninput_items, gr_vector_const_void_star &input_items,
-        gr_vector_void_star &output_items)
+        gr_vector_int &ninput_items __attribute__((unused)), gr_vector_const_void_star &input_items,
+        gr_vector_void_star &output_items __attribute__((unused)))
 {
 
     /*!
-     * TODO: 	High sensitivity acquisition algorithm:
-     * 			State Mechine:
-     * 			S0. StandBy. If d_active==1 -> S1
-     * 			S1. ComputeGrid. Perform the FFT acqusition doppler and delay grid.
-     * 				Accumulate the search grid matrix (#doppler_bins x #fft_size)
-     * 				Compare maximum to threshold and decide positive or negative
-     * 				If T>=gamma -> S4 else
-     * 				If d_well_count<max_dwells -> S2
-     * 				else -> S5.
-     * 			S4. Positive_Acq: Send message and stop acq -> S0
-     * 			S5. Negative_Acq: Send message and stop acq -> S0
+     * TODO:     High sensitivity acquisition algorithm:
+     *             State Mechine:
+     *             S0. StandBy. If d_active==1 -> S1
+     *             S1. ComputeGrid. Perform the FFT acqusition doppler and delay grid.
+     *                 Accumulate the search grid matrix (#doppler_bins x #fft_size)
+     *                 Compare maximum to threshold and decide positive or negative
+     *                 If T>=gamma -> S4 else
+     *                 If d_well_count<max_dwells -> S2
+     *                 else -> S5.
+     *             S4. Positive_Acq: Send message and stop acq -> S0
+     *             S5. Negative_Acq: Send message and stop acq -> S0
      */
 
     switch (d_state)
@@ -476,7 +486,7 @@ int pcps_acquisition_fine_doppler_cc::general_work(int noutput_items,
     case 3: // Fine doppler estimation
         //DLOG(INFO) <<"S3"<<std::endl;
         DLOG(INFO) << "Performing fine Doppler estimation";
-        estimate_Doppler(input_items, ninput_items[0]); //disabled in repo
+        estimate_Doppler(input_items); //disabled in repo
         d_state = 4;
         break;
     case 4: // Positive_Acq
@@ -491,8 +501,8 @@ int pcps_acquisition_fine_doppler_cc::general_work(int noutput_items,
         DLOG(INFO) << "input signal power " << d_input_power;
 
         d_active = false;
-        // Send message to channel queue //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
-        d_channel_internal_queue->push(1); // 1-> positive acquisition
+        // Send message to channel port //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
+        this->message_port_pub(pmt::mp("events"), pmt::from_long(1));
         d_state = 0;
         break;
     case 5: // Negative_Acq
@@ -507,8 +517,8 @@ int pcps_acquisition_fine_doppler_cc::general_work(int noutput_items,
         DLOG(INFO) << "input signal power " << d_input_power;
 
         d_active = false;
-        // Send message to channel queue //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
-        d_channel_internal_queue->push(2); // 2-> negative acquisition
+        // Send message to channel port //0=STOP_CHANNEL 1=ACQ_SUCCEES 2=ACQ_FAIL
+        this->message_port_pub(pmt::mp("events"), pmt::from_long(2));
         d_state = 0;
         break;
     default:
