@@ -63,19 +63,19 @@ pcps_tong_acquisition_cc_sptr pcps_tong_make_acquisition_cc(
                               unsigned int sampled_ms, unsigned int doppler_max,
                               long freq, long fs_in, int samples_per_ms,
                               int samples_per_code, unsigned int tong_init_val,
-                              unsigned int tong_max_val,
+                              unsigned int tong_max_val,  unsigned int tong_max_dwells,
                               bool dump, std::string dump_filename)
 {
     return pcps_tong_acquisition_cc_sptr(
             new pcps_tong_acquisition_cc(sampled_ms, doppler_max, freq, fs_in, samples_per_ms, samples_per_code,
-                                    tong_init_val, tong_max_val, dump, dump_filename));
+                                    tong_init_val, tong_max_val, tong_max_dwells, dump, dump_filename));
 }
 
 pcps_tong_acquisition_cc::pcps_tong_acquisition_cc(
                          unsigned int sampled_ms, unsigned int doppler_max,
                          long freq, long fs_in, int samples_per_ms,
                          int samples_per_code, unsigned int tong_init_val,
-                         unsigned int tong_max_val,
+                         unsigned int tong_max_val, unsigned int tong_max_dwells,
                          bool dump, std::string dump_filename) :
     gr::block("pcps_tong_acquisition_cc",
     gr::io_signature::make(1, 1, sizeof(gr_complex) * sampled_ms * samples_per_ms),
@@ -90,8 +90,9 @@ pcps_tong_acquisition_cc::pcps_tong_acquisition_cc(
     d_samples_per_ms = samples_per_ms;
     d_samples_per_code = samples_per_code;
     d_sampled_ms = sampled_ms;
-    d_well_count = 0;
+    d_dwell_count = 0;
     d_tong_max_val = tong_max_val;
+    d_tong_max_dwells = tong_max_dwells;
     d_tong_init_val = tong_init_val;
     d_tong_count = d_tong_init_val;
     d_doppler_max = doppler_max;
@@ -100,8 +101,8 @@ pcps_tong_acquisition_cc::pcps_tong_acquisition_cc(
     d_input_power = 0.0;
     d_num_doppler_bins = 0;
 
-    d_fft_codes = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
-    d_magnitude = static_cast<float*>(volk_malloc(d_fft_size * sizeof(float), volk_get_alignment()));
+    d_fft_codes = static_cast<gr_complex*>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
+    d_magnitude = static_cast<float*>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
 
     // Direct FFT
     d_fft_if = new gr::fft::fft_complex(d_fft_size, true);
@@ -131,15 +132,15 @@ pcps_tong_acquisition_cc::~pcps_tong_acquisition_cc()
         {
             for (unsigned int i = 0; i < d_num_doppler_bins; i++)
                 {
-                    volk_free(d_grid_doppler_wipeoffs[i]);
-                    volk_free(d_grid_data[i]);
+                    volk_gnsssdr_free(d_grid_doppler_wipeoffs[i]);
+                    volk_gnsssdr_free(d_grid_data[i]);
                 }
             delete[] d_grid_doppler_wipeoffs;
             delete[] d_grid_data;
         }
 
-    volk_free(d_fft_codes);
-    volk_free(d_magnitude);
+    volk_gnsssdr_free(d_fft_codes);
+    volk_gnsssdr_free(d_magnitude);
 
     delete d_ifft;
     delete d_fft_if;
@@ -188,7 +189,7 @@ void pcps_tong_acquisition_cc::init()
     d_grid_data = new float*[d_num_doppler_bins];
     for (unsigned int doppler_index = 0; doppler_index < d_num_doppler_bins; doppler_index++)
         {
-            d_grid_doppler_wipeoffs[doppler_index] = static_cast<gr_complex*>(volk_malloc(d_fft_size * sizeof(gr_complex), volk_get_alignment()));
+            d_grid_doppler_wipeoffs[doppler_index] = static_cast<gr_complex*>(volk_gnsssdr_malloc(d_fft_size * sizeof(gr_complex), volk_gnsssdr_get_alignment()));
 
             int doppler = -static_cast<int>(d_doppler_max) + d_doppler_step * doppler_index;
             float phase_step_rad = GPS_TWO_PI * (d_freq + doppler) / static_cast<float>(d_fs_in);
@@ -196,7 +197,7 @@ void pcps_tong_acquisition_cc::init()
             _phase[0] = 0;
             volk_gnsssdr_s32f_sincos_32fc(d_grid_doppler_wipeoffs[doppler_index], - phase_step_rad, _phase, d_fft_size);
 
-            d_grid_data[doppler_index] = static_cast<float*>(volk_malloc(d_fft_size * sizeof(float), volk_get_alignment()));
+            d_grid_data[doppler_index] = static_cast<float*>(volk_gnsssdr_malloc(d_fft_size * sizeof(float), volk_gnsssdr_get_alignment()));
 
             for (unsigned int i = 0; i < d_fft_size; i++)
                 {
@@ -213,8 +214,7 @@ void pcps_tong_acquisition_cc::set_state(int state)
             d_gnss_synchro->Acq_delay_samples = 0.0;
             d_gnss_synchro->Acq_doppler_hz = 0.0;
             d_gnss_synchro->Acq_samplestamp_samples = 0;
-            d_well_count = 0;
-            d_well_count = 0;
+            d_dwell_count = 0;
             d_tong_count = d_tong_init_val;
             d_mag = 0.0;
             d_input_power = 0.0;
@@ -252,7 +252,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
                     d_gnss_synchro->Acq_delay_samples = 0.0;
                     d_gnss_synchro->Acq_doppler_hz = 0.0;
                     d_gnss_synchro->Acq_samplestamp_samples = 0;
-                    d_well_count = 0;
+                    d_dwell_count = 0;
                     d_tong_count = d_tong_init_val;
                     d_mag = 0.0;
                     d_input_power = 0.0;
@@ -279,11 +279,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
         {
             // initialize acquisition algorithm
             int doppler;
-#if VOLK_GT_122
-            uint16_t indext = 0;
-#else
-            unsigned int indext = 0;
-#endif
+            uint32_t indext = 0;
             float magt = 0.0;
             const gr_complex *in = (const gr_complex *)input_items[0]; //Get the input samples pointer
             float fft_normalization_factor = static_cast<float>(d_fft_size) * static_cast<float>(d_fft_size);
@@ -292,7 +288,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
 
             d_sample_counter += d_fft_size; // sample counter
 
-            d_well_count++;
+            d_dwell_count++;
 
             DLOG(INFO) << "Channel: " << d_channel
                     << " , doing acquisition of satellite: " << d_gnss_synchro->System << " "<< d_gnss_synchro->PRN
@@ -339,7 +335,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
                     volk_32f_x2_add_32f(d_grid_data[doppler_index], d_magnitude, d_grid_data[doppler_index], d_fft_size);
 
                     // Search maximum
-                    volk_32f_index_max_16u(&indext, d_grid_data[doppler_index], d_fft_size);
+                    volk_gnsssdr_32f_index_max_32u(&indext, d_grid_data[doppler_index], d_fft_size);
 
                     magt = d_grid_data[doppler_index][indext];
 
@@ -370,7 +366,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
             // 5- Compute the test statistics and compare to the threshold
             d_test_statistics = d_mag;
 
-            if (d_test_statistics > d_threshold*d_well_count)
+            if (d_test_statistics > d_threshold * d_dwell_count)
                 {
                     d_tong_count++;
                     if (d_tong_count == d_tong_max_val)
@@ -387,6 +383,10 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
                         }
                 }
 
+            if(d_dwell_count >= d_tong_max_dwells)
+                {
+                    d_state = 3; // Negative acquisition
+                }
             consume_each(1);
 
             break;
