@@ -303,7 +303,7 @@ static inline void volk_gnsssdr_8ic_conjugate_8ic_neon(lv_8sc_t* cVector, const
     for (i = 0; i < sse_iters; ++i)
         {
             a_val = vld2_s8((const int8_t*)a);
-            __builtin_prefetch(a + 16);
+            __VOLK_GNSSSDR_PREFETCH(a + 16);
             a_val.val[1] = vneg_s8(a_val.val[1]);
             vst2_s8((int8_t*)c, a_val);
             a += 8;
