@@ -19,10 +19,10 @@
 #ifndef INCLUDED_VOLK_GNSSSDR_CONFIG_FIXED_H
 #define INCLUDED_VOLK_GNSSSDR_CONFIG_FIXED_H
 
-#for $i, $arch in enumerate($archs)
-#ifndef LV_$(arch.name.upper())
-#define LV_$(arch.name.upper()) $i
-#endif
-#end for
+%for i, arch in enumerate(archs):
+//#ifndef LV_${arch.name.upper()}
+#define LV_${arch.name.upper()} ${i}
+//#endif
+%endfor
 
 #endif /*INCLUDED_VOLK_GNSSSDR_CONFIG_FIXED*/
