@@ -33,6 +33,7 @@
 #include "sbas_l1_telemetry_decoder.h"
 #include <gnuradio/io_signature.h>
 #include <glog/logging.h>
+#include "concurrent_queue.h"
 #include "sbas_telemetry_data.h"
 #include "sbas_ionospheric_correction.h"
 #include "sbas_satellite_correction.h"
@@ -40,42 +41,24 @@
 #include "configuration_interface.h"
 #include "sbas_l1_telemetry_decoder_cc.h"
 
-extern concurrent_queue<Sbas_Raw_Msg> global_sbas_raw_msg_queue;
-extern concurrent_queue<Sbas_Ionosphere_Correction> global_sbas_iono_queue;
-extern concurrent_queue<Sbas_Satellite_Correction> global_sbas_sat_corr_queue;
-extern concurrent_queue<Sbas_Ephemeris> global_sbas_ephemeris_queue;
-
-
 using google::LogMessage;
 
 SbasL1TelemetryDecoder::SbasL1TelemetryDecoder(ConfigurationInterface* configuration,
         std::string role,
         unsigned int in_streams,
-        unsigned int out_streams,
-        boost::shared_ptr<gr::msg_queue> queue) :
+        unsigned int out_streams) :
         role_(role),
         in_streams_(in_streams),
-        out_streams_(out_streams),
-        queue_(queue)
+        out_streams_(out_streams)
 {
-    std::string default_item_type = "gr_complex";
     std::string default_dump_filename = "./navigation.dat";
     DLOG(INFO) << "role " << role;
-    DLOG(INFO) << "vector length " << vector_length_;
-    vector_length_ = configuration->property(role + ".vector_length", 2048);
     dump_ = configuration->property(role + ".dump", false);
     dump_filename_ = configuration->property(role + ".dump_filename", default_dump_filename);
-    int fs_in;
-    fs_in = configuration->property("GNSS-SDR.internal_fs_hz", 2048000);
     // make telemetry decoder object
-    telemetry_decoder_ = sbas_l1_make_telemetry_decoder_cc(satellite_, 0, (long)fs_in, vector_length_, queue_, dump_); // TODO fix me
+    telemetry_decoder_ = sbas_l1_make_telemetry_decoder_cc(satellite_, dump_); // TODO fix me
     channel_ = 0;
     DLOG(INFO) << "telemetry_decoder(" << telemetry_decoder_->unique_id() << ")";
-    // set the queues;
-    telemetry_decoder_->set_raw_msg_queue(&global_sbas_raw_msg_queue);
-    telemetry_decoder_->set_iono_queue(&global_sbas_iono_queue);
-    telemetry_decoder_->set_sat_corr_queue(&global_sbas_sat_corr_queue);
-    telemetry_decoder_->set_ephemeris_queue(&global_sbas_ephemeris_queue);
 }
 
 
@@ -93,16 +76,16 @@ void SbasL1TelemetryDecoder::set_satellite(Gnss_Satellite satellite)
 
 void SbasL1TelemetryDecoder::connect(gr::top_block_sptr top_block)
 {
-	if(top_block) { /* top_block is not null */};
-	// Nothing to connect internally
+    if(top_block) { /* top_block is not null */};
+    // Nothing to connect internally
     DLOG(INFO) << "nothing to connect internally";
 }
 
 
 void SbasL1TelemetryDecoder::disconnect(gr::top_block_sptr top_block)
 {
-	if(top_block) { /* top_block is not null */};
-	// Nothing to disconnect
+    if(top_block) { /* top_block is not null */};
+    // Nothing to disconnect
 }
 
 
