@@ -37,8 +37,8 @@
 #ifndef GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
 #define GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
 
+
 #include <string>
-#include <gnuradio/msg_queue.h>
 #include "tracking_interface.h"
 #include "galileo_e1_dll_pll_veml_tracking_cc.h"
 
@@ -51,14 +51,11 @@ class ConfigurationInterface;
  */
 class GalileoE1DllPllVemlTracking : public TrackingInterface
 {
-
 public:
-
-  GalileoE1DllPllVemlTracking(ConfigurationInterface* configuration,
+    GalileoE1DllPllVemlTracking(ConfigurationInterface* configuration,
             std::string role,
             unsigned int in_streams,
-            unsigned int out_streams,
-            boost::shared_ptr<gr::msg_queue> queue);
+            unsigned int out_streams);
 
     virtual ~GalileoE1DllPllVemlTracking();
 
@@ -95,25 +92,16 @@ public:
      */
     void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro);
 
-    /*!
-     * \brief Set tracking channel internal queue
-     */
-    void set_channel_queue(concurrent_queue<int> *channel_internal_queue);
 
     void start_tracking();
 
 private:
-
     galileo_e1_dll_pll_veml_tracking_cc_sptr tracking_;
     size_t item_size_;
-
     unsigned int channel_;
-
     std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    boost::shared_ptr<gr::msg_queue> queue_;
-    concurrent_queue<int> *channel_internal_queue_;
 };
 
 #endif // GNSS_SDR_GALILEO_E1_DLL_PLL_VEML_TRACKING_H_
