@@ -39,7 +39,6 @@
 #define GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_H_
 
 #include <string>
-#include <gnuradio/msg_queue.h>
 #include "tracking_interface.h"
 #include "gps_l1_ca_dll_pll_tracking_cc.h"
 
@@ -52,12 +51,10 @@ class ConfigurationInterface;
 class GpsL1CaDllPllTracking : public TrackingInterface
 {
 public:
-
-  GpsL1CaDllPllTracking(ConfigurationInterface* configuration,
+    GpsL1CaDllPllTracking(ConfigurationInterface* configuration,
             std::string role,
             unsigned int in_streams,
-            unsigned int out_streams,
-            boost::shared_ptr<gr::msg_queue> queue);
+            unsigned int out_streams);
 
     virtual ~GpsL1CaDllPllTracking();
 
@@ -71,6 +68,7 @@ public:
     {
         return "GPS_L1_CA_DLL_PLL_Tracking";
     }
+
     size_t item_size()
     {
         return item_size_;
@@ -81,7 +79,6 @@ public:
     gr::basic_block_sptr get_left_block();
     gr::basic_block_sptr get_right_block();
 
-
     /*!
      * \brief Set tracking channel unique ID
      */
@@ -93,11 +90,6 @@ public:
      */
     void set_gnss_synchro(Gnss_Synchro* p_gnss_synchro);
 
-    /*!
-     * \brief Set tracking channel internal queue
-     */
-    void set_channel_queue(concurrent_queue<int> *channel_internal_queue);
-
     void start_tracking();
 
 private:
@@ -107,8 +99,6 @@ private:
     std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    boost::shared_ptr<gr::msg_queue> queue_;
-    concurrent_queue<int> *channel_internal_queue_;
 };
 
 #endif // GNSS_SDR_GPS_L1_CA_DLL_PLL_TRACKING_H_
