@@ -34,10 +34,14 @@
 
 #include "gnss_flowgraph.h"
 #include "unistd.h"
+
+#include <memory>
+#include <algorithm>
 #include <exception>
 #include <iostream>
 #include <set>
 #include <boost/lexical_cast.hpp>
+#include <boost/tokenizer.hpp>
 #include <glog/logging.h>
 #include "configuration_interface.h"
 #include "gnss_block_interface.h"
@@ -62,6 +66,7 @@ GNSSFlowgraph::GNSSFlowgraph(std::shared_ptr<ConfigurationInterface> configurati
 GNSSFlowgraph::~GNSSFlowgraph()
 {}
 
+
 void GNSSFlowgraph::start()
 {
     if (running_)
@@ -87,12 +92,12 @@ void GNSSFlowgraph::start()
 
 void GNSSFlowgraph::stop()
 {
-    for (unsigned int i = 0; i < channels_count_; i++)
-        {
-            channels_.at(i)->stop();
-            LOG(INFO) << "Channel " << i << " in state " << channels_state_[i];
-        }
-    LOG(INFO) << "Threads finished. Return to main program.";
+    //    for (unsigned int i = 0; i < channels_count_; i++)
+    //        {
+    //            channels_.at(i)->stop_channel();
+    //            LOG(INFO) << "Channel " << i << " in state " << channels_state_[i];
+    //        }
+    //    LOG(INFO) << "Threads finished. Return to main program.";
     top_block_->stop();
     running_ = false;
 }
@@ -102,7 +107,7 @@ void GNSSFlowgraph::connect()
 {
     /* Connects the blocks in the flowgraph
      *
-     * Signal Source > Signal conditioner >> Channels >> Observables >> PVT > Output filter
+     * Signal Source > Signal conditioner >> Channels >> Observables >> PVT
      */
     LOG(INFO) << "Connecting flowgraph";
     if (connected_)
@@ -182,21 +187,7 @@ void GNSSFlowgraph::connect()
             return;
     }
 
-    // Signal Source > Signal conditioner >> Channels >> Observables > PVT > Output Filter
-    try
-    {
-            output_filter_->connect(top_block_);
-    }
-    catch (std::exception& e)
-    {
-            LOG(WARNING) << "Can't connect output filter block internally";
-            LOG(ERROR) << e.what();
-            top_block_->disconnect_all();
-            return;
-    }
-
     DLOG(INFO) << "blocks connected internally";
-
     // Signal Source (i) >  Signal conditioner (i) >
     int RF_Channels = 0;
     int signal_conditioner_ID = 0;
@@ -266,7 +257,6 @@ void GNSSFlowgraph::connect()
                     return;
             }
         }
-
     DLOG(INFO) << "Signal source connected to signal conditioner";
 
     // Signal conditioner (selected_signal_source) >> channels (i) (dependent of their associated SignalSource_ID)
@@ -303,22 +293,19 @@ void GNSSFlowgraph::connect()
                     return;
             }
 
-            std::string default_signal = configuration_->property("Channel.signal", std::string("1C"));
-            std::string gnss_signal = (configuration_->property("Channel" + boost::lexical_cast<std::string>(i) + ".signal", default_signal));
-
+            std::string gnss_signal = channels_.at(i)->get_signal().get_signal_str(); // use channel's implicit signal!
             while (gnss_signal.compare(available_GNSS_signals_.front().get_signal_str()) != 0 )
                 {
                     available_GNSS_signals_.push_back(available_GNSS_signals_.front());
                     available_GNSS_signals_.pop_front();
                 }
             channels_.at(i)->set_signal(available_GNSS_signals_.front());
-            LOG(INFO) << "Channel " << i << " assigned to " << available_GNSS_signals_.front();
-            available_GNSS_signals_.pop_front();
-            channels_.at(i)->start();
 
             if (channels_state_[i] == 1)
                 {
                     channels_.at(i)->start_acquisition();
+                    available_GNSS_signals_.pop_front();
+                    LOG(INFO) << "Channel " << i << " assigned to " << available_GNSS_signals_.front();
                     LOG(INFO) << "Channel " << i << " connected to observables and ready for acquisition";
                 }
             else
@@ -335,6 +322,7 @@ void GNSSFlowgraph::connect()
             for (unsigned int i = 0; i < channels_count_; i++)
                 {
                     top_block_->connect(observables_->get_right_block(), i, pvt_->get_left_block(), i);
+                    top_block_->msg_connect(channels_.at(i)->get_right_block(), pmt::mp("telemetry"), pvt_->get_left_block(), pmt::mp("telemetry"));
                 }
     }
     catch (std::exception& e)
@@ -345,27 +333,12 @@ void GNSSFlowgraph::connect()
             return;
     }
 
-    try
-    {
-            top_block_->connect(pvt_->get_right_block(), 0, output_filter_->get_left_block(), 0);
-    }
-    catch (std::exception& e)
-    {
-            LOG(WARNING) << "Can't connect PVT to output filter";
-            LOG(ERROR) << e.what();
-            top_block_->disconnect_all();
-            return;
-    }
-
-    DLOG(INFO) << "PVT connected to output filter";
     connected_ = true;
     LOG(INFO) << "Flowgraph connected";
     top_block_->dump();
 }
 
 
-
-
 void GNSSFlowgraph::wait()
 {
     if (!running_)
@@ -379,6 +352,14 @@ void GNSSFlowgraph::wait()
 }
 
 
+bool GNSSFlowgraph::send_telemetry_msg(pmt::pmt_t msg)
+{
+    //push ephemeris to PVT telemetry msg in port using a channel out port
+    // it uses the first channel as a message produces (it is already connected to PVT)
+    channels_.at(0)->get_right_block()->message_port_pub(pmt::mp("telemetry"), msg);
+    return true;
+}
+
 /*
  * Applies an action to the flowgraph
  *
@@ -394,7 +375,6 @@ void GNSSFlowgraph::apply_action(unsigned int who, unsigned int what)
     case 0:
         LOG(INFO) << "Channel " << who << " ACQ FAILED satellite " << channels_.at(who)->get_signal().get_satellite() << ", Signal " << channels_.at(who)->get_signal().get_signal_str();
         available_GNSS_signals_.push_back(channels_.at(who)->get_signal());
-
         //TODO: Optimize the channel and signal matching!
         while ( channels_.at(who)->get_signal().get_signal_str().compare(available_GNSS_signals_.front().get_signal_str()) != 0 )
             {
@@ -403,23 +383,27 @@ void GNSSFlowgraph::apply_action(unsigned int who, unsigned int what)
             }
         channels_.at(who)->set_signal(available_GNSS_signals_.front());
         available_GNSS_signals_.pop_front();
-
+        usleep(100);
         channels_.at(who)->start_acquisition();
-
         break;
-        // TODO: Tracking messages
-
     case 1:
         LOG(INFO) << "Channel " << who << " ACQ SUCCESS satellite " << channels_.at(who)->get_signal().get_satellite();
         channels_state_[who] = 2;
         acq_channels_count_--;
-        if (acq_channels_count_ < max_acq_channels_)
+        if (!available_GNSS_signals_.empty() && acq_channels_count_ < max_acq_channels_)
             {
                 for (unsigned int i = 0; i < channels_count_; i++)
                     {
                         if (channels_state_[i] == 0)
                             {
                                 channels_state_[i] = 1;
+                                while (channels_.at(i)->get_signal().get_signal_str().compare(available_GNSS_signals_.front().get_signal_str()) != 0 )
+                                    {
+                                        available_GNSS_signals_.push_back(available_GNSS_signals_.front());
+                                        available_GNSS_signals_.pop_front();
+                                    }
+                                channels_.at(i)->set_signal(available_GNSS_signals_.front());
+                                available_GNSS_signals_.pop_front();
                                 acq_channels_count_++;
                                 channels_.at(i)->start_acquisition();
                                 break;
@@ -441,7 +425,7 @@ void GNSSFlowgraph::apply_action(unsigned int who, unsigned int what)
         else
             {
                 channels_state_[who] = 0;
-                channels_.at(who)->standby();
+                available_GNSS_signals_.push_back( channels_.at(who)->get_signal() );
             }
 
         // for (unsigned int i = 0; i < channels_count_; i++)
@@ -480,7 +464,7 @@ void GNSSFlowgraph::init()
     /*
      * Instantiates the receiver blocks
      */
-    std::shared_ptr<GNSSBlockFactory> block_factory_ = std::make_shared<GNSSBlockFactory>();
+    std::unique_ptr<GNSSBlockFactory> block_factory_(new GNSSBlockFactory());
 
     // 1. read the number of RF front-ends available (one file_source per RF front-end)
     sources_count_ = configuration_->property("Receiver.sources_count", 1);
@@ -501,7 +485,7 @@ void GNSSFlowgraph::init()
                     std::cout << "RF Channels " << RF_Channels << std::endl;
                     for (int j = 0; j < RF_Channels; j++)
                         {
-                            sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, queue_, signal_conditioner_ID));
+                            sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, signal_conditioner_ID));
                             signal_conditioner_ID++;
                         }
                 }
@@ -518,23 +502,23 @@ void GNSSFlowgraph::init()
                 {
                     for (int j = 0; j < RF_Channels; j++)
                         {
-                            sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, queue_, signal_conditioner_ID));
+                            sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, signal_conditioner_ID));
                             signal_conditioner_ID++;
                         }
                 }
             else
                 {
                     //old config file, single signal source and single channel, not specified
-                    sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, queue_, -1));
+                    sig_conditioner_.push_back(block_factory_->GetSignalConditioner(configuration_, -1));
                 }
         }
 
-    observables_ = block_factory_->GetObservables(configuration_, queue_);
-    pvt_ = block_factory_->GetPVT(configuration_, queue_);
-    output_filter_ = block_factory_->GetOutputFilter(configuration_, queue_);
+    observables_ = block_factory_->GetObservables(configuration_);
+    pvt_ = block_factory_->GetPVT(configuration_);
 
     std::shared_ptr<std::vector<std::unique_ptr<GNSSBlockInterface>>> channels = block_factory_->GetChannels(configuration_, queue_);
 
+    //todo:check smart pointer coherence...
     channels_count_ = channels->size();
     for (unsigned int i = 0; i < channels_count_; i++)
         {
@@ -568,13 +552,9 @@ void GNSSFlowgraph::set_signals_list()
     /*
      * Read GNSS-SDR default GNSS system and signal
      */
-    std::string default_system = configuration_->property("Channel.system", std::string("")); // DEPRECATED
-    std::string default_signal = configuration_->property("Channel.signal", std::string(""));
 
-    unsigned int total_channels = configuration_->property("Channels_GPS.count", 0) +
-            configuration_->property("Channels_1C.count", 0) +
+    unsigned int total_channels = configuration_->property("Channels_1C.count", 0) +
             configuration_->property("Channels_2S.count", 0) +
-            configuration_->property("Channels_Galileo.count", 0) +
             configuration_->property("Channels_1B.count", 0) +
             configuration_->property("Channels_5X.count", 0);
 
@@ -593,9 +573,55 @@ void GNSSFlowgraph::set_signals_list()
                     11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28,
                     29, 30, 31, 32, 33, 34, 35, 36};
 
+    std::string sv_list = configuration_->property("Galileo.prns", std::string("") );
 
+    if( sv_list.length() > 0 )
+        {
+            // Reset the available prns:
+            std::set< unsigned int > tmp_set;
+            boost::tokenizer<> tok( sv_list );
+            std::transform( tok.begin(), tok.end(), std::inserter( tmp_set, tmp_set.begin() ),
+                    boost::lexical_cast<unsigned int, std::string> );
 
-    if ((configuration_->property("Channels_1C.count", 0) > 0) or (default_system.find(std::string("GPS")) != std::string::npos) or (default_signal.compare("1C") == 0) or (configuration_->property("Channels_GPS.count", 0) > 0) )
+            if( tmp_set.size() > 0 )
+                {
+                    available_galileo_prn = tmp_set;
+                }
+        }
+
+    sv_list = configuration_->property("GPS.prns", std::string("") );
+
+    if( sv_list.length() > 0 )
+        {
+            // Reset the available prns:
+            std::set< unsigned int > tmp_set;
+            boost::tokenizer<> tok( sv_list );
+            std::transform( tok.begin(), tok.end(), std::inserter( tmp_set, tmp_set.begin() ),
+                    boost::lexical_cast<unsigned int, std::string> );
+
+            if( tmp_set.size() > 0 )
+                {
+                    available_gps_prn = tmp_set;
+                }
+        }
+
+    sv_list = configuration_->property("SBAS.prns", std::string("") );
+
+    if( sv_list.length() > 0 )
+        {
+            // Reset the available prns:
+            std::set< unsigned int > tmp_set;
+            boost::tokenizer<> tok( sv_list );
+            std::transform( tok.begin(), tok.end(), std::inserter( tmp_set, tmp_set.begin() ),
+                    boost::lexical_cast<unsigned int, std::string> );
+
+            if( tmp_set.size() > 0 )
+                {
+                    available_sbas_prn = tmp_set;
+                }
+        }
+
+    if (configuration_->property("Channels_1C.count", 0) > 0 )
         {
             /*
              * Loop to create GPS L1 C/A signals
@@ -609,7 +635,7 @@ void GNSSFlowgraph::set_signals_list()
                 }
         }
 
-    if ((configuration_->property("Channels_2S.count", 0) > 0) or (default_system.find(std::string("GPS L2C M")) != std::string::npos) )
+    if (configuration_->property("Channels_2S.count", 0) > 0)
         {
             /*
              * Loop to create GPS L2C M signals
@@ -623,8 +649,7 @@ void GNSSFlowgraph::set_signals_list()
                 }
         }
 
-
-    if ((configuration_->property("Channels_SBAS.count", 0) > 0) or default_system.find(std::string("SBAS")) != std::string::npos)
+    if (configuration_->property("Channels_SBAS.count", 0) > 0)
         {
             /*
              * Loop to create SBAS L1 C/A signals
@@ -639,7 +664,7 @@ void GNSSFlowgraph::set_signals_list()
         }
 
 
-    if ((configuration_->property("Channels_1B.count", 0) > 0) or (default_system.find(std::string("Galileo")) != std::string::npos) or (default_signal.compare("1B") == 0) or (configuration_->property("Channels_Galileo.count", 0) > 0))
+    if (configuration_->property("Channels_1B.count", 0) > 0)
         {
             /*
              * Loop to create the list of Galileo E1 B signals
@@ -653,7 +678,7 @@ void GNSSFlowgraph::set_signals_list()
                 }
         }
 
-    if ((configuration_->property("Channels_5X.count", 0) > 0) )
+    if (configuration_->property("Channels_5X.count", 0) > 0 )
         {
             /*
              * Loop to create the list of Galileo E1 B signals
@@ -666,47 +691,40 @@ void GNSSFlowgraph::set_signals_list()
                             *available_gnss_prn_iter), std::string("5X")));
                 }
         }
-
     /*
      * Ordering the list of signals from configuration file
      */
     std::list<Gnss_Signal>::iterator gnss_it = available_GNSS_signals_.begin();
 
-    // Preassignation if not defined at ChannelX.signal=1C ...? In what order?
+    // Pre-assignation if not defined at ChannelX.signal=1C ...? In what order?
 
     for (unsigned int i = 0; i < total_channels; i++)
         {
-            std::string gnss_signal = (configuration_->property("Channel" + boost::lexical_cast<std::string>(i) + ".signal", default_signal));
+            std::string gnss_signal = (configuration_->property("Channel" + boost::lexical_cast<std::string>(i) + ".signal", std::string("1C")));
             std::string gnss_system;
             if((gnss_signal.compare("1C") == 0) or (gnss_signal.compare("2S") == 0) ) gnss_system = "GPS";
             if((gnss_signal.compare("1B") == 0) or (gnss_signal.compare("5X") == 0) ) gnss_system = "Galileo";
-
-            LOG(INFO) << "Channel " << i <<  " system " << gnss_system << ", signal " << gnss_signal;
-
             unsigned int sat = configuration_->property("Channel" + boost::lexical_cast<std::string>(i) + ".satellite", 0);
-
-            if (((sat == 0) || (sat == gnss_it->get_satellite().get_PRN()))  and  ( gnss_it->get_signal_str().compare(gnss_signal) == 0 )  ) // 0 = not PRN in configuration file
+            LOG(INFO) << "Channel " << i <<  " system " << gnss_system << ", signal " << gnss_signal <<", sat "<<sat;
+            if (sat == 0) // 0 = not PRN in configuration file
                 {
                     gnss_it++;
                 }
             else
                 {
-                    Gnss_Signal signal_value = Gnss_Signal(Gnss_Satellite(gnss_system, gnss_it->get_satellite().get_PRN()), gnss_signal);
+                    Gnss_Signal signal_value = Gnss_Signal(Gnss_Satellite(gnss_system, sat), gnss_signal);
                     available_GNSS_signals_.remove(signal_value);
                     available_GNSS_signals_.insert(gnss_it, signal_value);
                 }
         }
 
-        //    **** FOR DEBUGGING THE LIST OF GNSS SIGNALS ****
-
-        // std::cout << "default_system=" << default_system << std::endl;
-        // std::cout << "default_signal=" << default_signal << std::endl;
-        //    std::list<Gnss_Signal>::iterator available_gnss_list_iter;
-        //    for (available_gnss_list_iter = available_GNSS_signals_.begin(); available_gnss_list_iter
-        //    != available_GNSS_signals_.end(); available_gnss_list_iter++)
-        //    {
-        //      std::cout << *available_gnss_list_iter << std::endl;
-        //    }
+    //    **** FOR DEBUGGING THE LIST OF GNSS SIGNALS ****
+    //    std::list<Gnss_Signal>::iterator available_gnss_list_iter;
+    //    for (available_gnss_list_iter = available_GNSS_signals_.begin(); available_gnss_list_iter
+    //    != available_GNSS_signals_.end(); available_gnss_list_iter++)
+    //        {
+    //            std::cout << *available_gnss_list_iter << std::endl;
+    //        }
 }
 
 
@@ -716,8 +734,7 @@ void GNSSFlowgraph::set_channels_state()
     if (max_acq_channels_ > channels_count_)
         {
             max_acq_channels_ = channels_count_;
-            LOG(WARNING) << "Channels_in_acquisition is bigger than number of channels. Variable acq_channels_count_ is set to "
-                         << channels_count_;
+            LOG(WARNING) << "Channels_in_acquisition is bigger than number of channels. Variable acq_channels_count_ is set to " << channels_count_;
         }
     channels_state_.reserve(channels_count_);
     for (unsigned int i = 0; i < channels_count_; i++)
