@@ -32,29 +32,25 @@
 #ifndef GNSS_SDR_GPS_CNAV_EPHEMERIS_H_
 #define GNSS_SDR_GPS_CNAV_EPHEMERIS_H_
 
-#include <iostream>
-#include <map>
-#include <string>
 #include "boost/assign.hpp"
 #include <boost/serialization/nvp.hpp>
-#include "GPS_L2C.h"
 
 
 /*!
- * \brief This class is a storage and orbital model functions for the GPS SV ephemeris data as described in IS-GPS-200E
+ * \brief This class is a storage and orbital model functions for the GPS SV ephemeris data as described in IS-GPS-200H
  *
- * See http://www.gps.gov/technical/icwg/IS-GPS-200E.pdf Appendix II
+ * See http://www.gps.gov/technical/icwg/IS-GPS-200H.pdf Appendix III
  */
 class Gps_CNAV_Ephemeris
 {
 private:
-
+    double check_t(double time);
 public:
     unsigned int i_satellite_PRN; // SV PRN NUMBER
 
     //Message Types 10 and 11 Parameters (1 of 2)
     int i_GPS_week;          //!< GPS week number, aka WN [week]
-    int i_URA;	             //!< ED Accuracy Index
+    int i_URA;               //!< ED Accuracy Index
     int i_signal_health;     //!< Signal health (L1/L2/L5)
     double d_Top;            //!< Data predict time of week
     double d_DELTA_A;        //!< Semi-major axis difference at reference time
@@ -168,6 +164,23 @@ public:
         archive & make_nvp("b_antispoofing_flag", b_antispoofing_flag); //!<  If true, the AntiSpoofing mode is ON in that SV
     }
 
+    /*!
+     * \brief Compute the ECEF SV coordinates and ECEF velocity
+     * Implementation of Table 20-IV (IS-GPS-200E)
+     */
+    void satellitePosition(double transmitTime);
+
+    /*!
+     * \brief Sets (\a d_satClkDrift)and returns the clock drift in seconds according to the User Algorithm for SV Clock Correction
+     *  (IS-GPS-200E,  20.3.3.3.3.1)
+     */
+    double sv_clock_drift(double transmitTime);
+
+    /*!
+     * \brief Sets (\a d_dtr) and returns the clock relativistic correction term in seconds according to the User Algorithm for SV Clock Correction
+     *  (IS-GPS-200E,  20.3.3.3.3.1)
+     */
+    double sv_clock_relativistic_term(double transmitTime);
     /*!
      * Default constructor
      */
