@@ -98,10 +98,6 @@ class Sbas_Telemetry_Data
 {
 public:
     int update(Sbas_Raw_Msg sbas_raw_msg);
-    void set_raw_msg_queue(concurrent_queue<Sbas_Raw_Msg> *raw_msg_queue);
-    void set_iono_queue(concurrent_queue<Sbas_Ionosphere_Correction> *iono_queue);
-    void set_sat_corr_queue(concurrent_queue<Sbas_Satellite_Correction> *sat_corr_queue);
-    void set_ephemeris_queue(concurrent_queue<Sbas_Ephemeris> *ephemeris_queue);
 
     /*!
      * Default constructor
@@ -118,11 +114,6 @@ private:
 
     Sbas_Time_Relation mt12_time_ref;
 
-    concurrent_queue<Sbas_Raw_Msg> *raw_msg_queue;
-    concurrent_queue<Sbas_Ionosphere_Correction> *iono_queue;
-    concurrent_queue<Sbas_Satellite_Correction> *sat_corr_queue;
-    concurrent_queue<Sbas_Ephemeris> *ephemeris_queue;
-
     int decode_mt12(Sbas_Raw_Msg sbas_raw_msg);
 
     void updated_sbas_ephemeris(Sbas_Raw_Msg msg);
@@ -276,7 +267,7 @@ private:
 
     typedef struct {        /* SBAS long term satellite error correction type */
         //gtime_t t0;         /* correction time */
-        double trx;	    /* time when message was received */
+        double trx;        /* time when message was received */
         int tapp;           /* time of applicability (when vel=1 sent as t0) */
         int vel;            /* use velocity if vel=1 */
         bool valid;
